package org.jeecg.modules.demo.ggzyindustrytype.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.demo.ggzyindustrytype.entity.GgzyIndustryType;
import org.jeecg.modules.demo.ggzyindustrytype.service.IGgzyIndustryTypeService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 公共资源行业类型
 * @Author: jeecg-boot
 * @Date:   2024-01-08
 * @Version: V1.0
 */
@Api(tags="公共资源行业类型")
@RestController
@RequestMapping("/ggzyindustrytype/ggzyIndustryType")
@Slf4j
public class GgzyIndustryTypeController extends JeecgController<GgzyIndustryType, IGgzyIndustryTypeService> {
	@Autowired
	private IGgzyIndustryTypeService ggzyIndustryTypeService;
	
	/**
	 * 分页列表查询
	 *
	 * @param ggzyIndustryType
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "公共资源行业类型-分页列表查询")
	@ApiOperation(value="公共资源行业类型-分页列表查询", notes="公共资源行业类型-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<GgzyIndustryType>> queryPageList(GgzyIndustryType ggzyIndustryType,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<GgzyIndustryType> queryWrapper = QueryGenerator.initQueryWrapper(ggzyIndustryType, req.getParameterMap());
		Page<GgzyIndustryType> page = new Page<GgzyIndustryType>(pageNo, pageSize);
		IPage<GgzyIndustryType> pageList = ggzyIndustryTypeService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param ggzyIndustryType
	 * @return
	 */
	@AutoLog(value = "公共资源行业类型-添加")
	@ApiOperation(value="公共资源行业类型-添加", notes="公共资源行业类型-添加")
	@RequiresPermissions("ggzyindustrytype:ggzy_industry_type:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody GgzyIndustryType ggzyIndustryType) {
		ggzyIndustryTypeService.save(ggzyIndustryType);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param ggzyIndustryType
	 * @return
	 */
	@AutoLog(value = "公共资源行业类型-编辑")
	@ApiOperation(value="公共资源行业类型-编辑", notes="公共资源行业类型-编辑")
	@RequiresPermissions("ggzyindustrytype:ggzy_industry_type:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody GgzyIndustryType ggzyIndustryType) {
		ggzyIndustryTypeService.updateById(ggzyIndustryType);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "公共资源行业类型-通过id删除")
	@ApiOperation(value="公共资源行业类型-通过id删除", notes="公共资源行业类型-通过id删除")
	@RequiresPermissions("ggzyindustrytype:ggzy_industry_type:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		ggzyIndustryTypeService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "公共资源行业类型-批量删除")
	@ApiOperation(value="公共资源行业类型-批量删除", notes="公共资源行业类型-批量删除")
	@RequiresPermissions("ggzyindustrytype:ggzy_industry_type:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.ggzyIndustryTypeService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "公共资源行业类型-通过id查询")
	@ApiOperation(value="公共资源行业类型-通过id查询", notes="公共资源行业类型-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<GgzyIndustryType> queryById(@RequestParam(name="id",required=true) String id) {
		GgzyIndustryType ggzyIndustryType = ggzyIndustryTypeService.getById(id);
		if(ggzyIndustryType==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(ggzyIndustryType);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param ggzyIndustryType
    */
    @RequiresPermissions("ggzyindustrytype:ggzy_industry_type:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, GgzyIndustryType ggzyIndustryType) {
        return super.exportXls(request, ggzyIndustryType, GgzyIndustryType.class, "公共资源行业类型");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("ggzyindustrytype:ggzy_industry_type:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, GgzyIndustryType.class);
    }

}
